
#------------------------------------------------------------------------------
# Name          : delete_port.tcl
# Author        : 
# Purpose       : Using Virtual Chassis Builder APIs add a Card to Chassis. Fetch Card details & Delete Cards from Chassis using API. 
# Test Steps    : 1. View Chassis Topology.
#				  2. Add a Card to Chassis . 
#                 4. Delete Ports from the Card.     
#
# Prerequisite  : A Chassis & Card is already deployed & reachable.
#------------------------------------------------------------------------------

# You defined Deployed Chassis IP & Deployed Card IP this this file 
source common.tcl

#-----------------------------------
# setup path and load IxLoad package
#-----------------------------------
source ../setup_simple.tcl
#Manual
# source "C:/Program Files (x86)/Ixia/IxLoad/8.20.0.206-EB/TclScripts/bin/IxiaWish.tcl"
# package require IxLoad

#-------------------------------------
# Initialize IxLoad
#-------------------------------------

#IxLoad connect should always be called, even for local scripts
# ::IxLoad connect 1.2.3.4

::IxLoad connect $::IxLoadPrivate::SimpleSettings::remoteServer

#--------------------------------------
# setup logger
#--------------------------------------
set logtag "IxLoad-api"
set logName "cbapi_log"
set logger [::IxLoad new ixLogger $logtag 1]
set logEngine [$logger getEngine]
$logEngine setLevels $::ixLogger(kLevelDebug) $::ixLogger(kLevelInfo)
$logEngine setFile $logName 2 256 1

puts "#############################################"
puts "Starting Sample Test : delete_port.tcl "
puts "#############################################"
puts ""
puts "-------------------------------------------------------------"
puts "Conneting to the Chassis : $chassisIP (This Is Your Deployed Chassis IP!)"
puts "--------------------------------------------------------------"

set chassisBuilder [::IxLoad new ixChassisBuilder]
$chassisBuilder connectToChassis  -chassisName $chassisIP
puts $chassisBuilder

puts "Starting getChassisTopology API"
puts "------------------------------------"
set topologies [$chassisBuilder getChassisTopology ]
set count      [$topologies indexCount]
puts "Number of cards before add/delete: $count"
if {$count != 0} {
    puts "Deleting all existing cards.."
	for {set index 0} {$index < $count} {incr index} {
		set topology     [$topologies getItem $index]
		puts "topology: $topology"
		set CardServerId     [$topology cget -CardServerId]
		$chassisBuilder deleteCard -cardId $CardServerId
    }
}


puts ""
puts "-------------------------------------------------------"
puts "Add new Card ( $cardIP ) to Chassis with two ports(eth1 & eth2) .."
puts "-------------------------------------------------------"

set CardServerId 1
#$chassisBuilder addCard -managementIp $cardIP -cardServerId $CardServerId -keepAliveTimeout 300
$chassisBuilder addCard -managementIp $cardIP
set cardId [$chassisBuilder getIxVMCardByIP -managementIp $cardIP]
puts "Adding 2 ports to card $cardId"
$chassisBuilder addPort -cardId $CardServerId -portId 1 -interfaceName "eth1" -promiscMode True
$chassisBuilder addPort -cardId $CardServerId -portId 2 -interfaceName "eth2" -promiscMode True
$chassisBuilder connectCard -cardId $CardServerId

after 1000

set topologies      [$chassisBuilder getChassisTopology ]
set count           [$topologies indexCount]
puts "After Adding 2 Ports, There are total $count ports Now."

puts ""
puts "---------------------------------------------"
puts "Removing one port from Card $CardServerId"
puts "---------------------------------------------"
$chassisBuilder removePortById -cardId $CardServerId -portId 2
set topologies      [$chassisBuilder getChassisTopology ]
set count           [$topologies indexCount]
puts "After Removing one port, There are total $count ports."
puts ""

#################
#   TEST END    #
#################
::IxLoad disconnect
